import {Component, OnDestroy} from '@angular/core';
import {AvatarModule} from 'primeng/avatar';
import {Button, ButtonDirective} from 'primeng/button';
import {AuthorService} from '../services/author.service';
import {Author} from '../model/author';
import {JsonPipe} from '@angular/common';
import {Subscription} from 'rxjs';

@Component({
  selector: 'app-home',
  standalone: true,
  imports: [
    AvatarModule,
    ButtonDirective,
    Button,
    JsonPipe
  ],
  templateUrl: './home.component.html',
  styleUrl: './home.component.css'
})
export class HomeComponent implements OnDestroy {
  authors: Author[] = []
  subs: Subscription[] = []

  constructor(private authorService: AuthorService) {
    this.subs.push(authorService.list()
      .subscribe({
        next: (authors: Author[]) => this.authors = authors,
        error: (err) => console.error(err.message),
      }));
  }

  ngOnDestroy(): void {
    this.subs.forEach(sub => sub.unsubscribe());
  }

}
